@@ -1,12 +1,11 @@
 #
 # This file is part of pysmi software.
 #
-# Copyright (c) 2015-2019, Ilya Etingof <etingof@gmail.com>
-# License: http://snmplabs.com/pysmi/license.html
+# Copyright (c) 2015-2020, Ilya Etingof <etingof@gmail.com>
+# License: https://www.pysnmp.com/pysmi/license.html
 #
 from pysmi.reader.callback import CallbackReader
-from pysmi.reader.ftpclient import FtpReader
 from pysmi.reader.httpclient import HttpReader
-from pysmi.reader.zipreader import ZipReader
 from pysmi.reader.localfile import FileReader
-from pysmi.reader.url import getReadersFromUrls
+from pysmi.reader.url import get_readers_from_urls
+from pysmi.reader.zipreader import ZipReader
